==> ruta-3.3.0-source-release.zip: ruta-3.3.0/ruta-core/src/main/java/org/apache/uima/ruta/expression/annotation/AbstractAnnotationExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.expression.annotation;

import org.apache.uima.cas.FeatureStructure;
import org.apache.uima.cas.text.AnnotationFS;
import org.apache.uima.ruta.RutaStream;
import org.apache.uima.ruta.expression.RutaExpression;
import org.apache.uima.ruta.rule.MatchContext;

public abstract class AbstractAnnotationExpression extends RutaExpression implements IAnnotationExpression {

  @Override
  public FeatureStructure getFeatureStructure(MatchContext context, RutaStream stream) {
    return getAnnotation(context, stream);
  }
  
  @Override
  public String getStringValue(MatchContext context, RutaStream stream) {
    AnnotationFS annotation = getAnnotation(context, stream);
    if(annotation != null) {
      return annotation.getCoveredText();
    } else {
      return "null";
    }
  }
  
}

==> ruta-3.4.0-source-release.zip: ruta-3.4.0/ruta-core/src/main/java/org/apache/uima/ruta/expression/annotation/AbstractAnnotationExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.expression.annotation;

import org.apache.uima.cas.FeatureStructure;
import org.apache.uima.cas.text.AnnotationFS;
import org.apache.uima.ruta.RutaStream;
import org.apache.uima.ruta.expression.RutaExpression;
import org.apache.uima.ruta.rule.MatchContext;

public abstract class AbstractAnnotationExpression extends RutaExpression
        implements IAnnotationExpression {

  @Override
  public FeatureStructure getFeatureStructure(MatchContext context, RutaStream stream) {
    return getAnnotation(context, stream);
  }

  @Override
  public String getStringValue(MatchContext context, RutaStream stream) {
    AnnotationFS annotation = getAnnotation(context, stream);
    if (annotation != null) {
      return annotation.getCoveredText();
    }
    return "null";
  }

}
